@@ -1,4 +1,5 @@
-package Finance::CoinbasePro::API::CLI; # Command-line interface to GDAX / Coinbase Pro
+package Finance::CoinbasePro::API::CLI
+  ;    # Command-line interface to GDAX / Coinbase Pro
 
 use 5.006;
 use strict;
@@ -10,8 +11,7 @@ Finance::CoinbasePro::API::CLI - Command-line interface to GDAX / Coinbase Pro
 
 =cut
 
-our $VERSION = '0.004';
-
+our $VERSION = '0.005';
 
 =head1 SYNOPSIS
 
@@ -89,16 +89,7 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1; # End of Finance::CoinbasePro::API::CLI
-
-
-
-
-
-
-
-
-
+1;    # End of Finance::CoinbasePro::API::CLI
 
 #################### pod generated by Pod::Autopod - keep this line to make pod updates possible ####################
 
